#[repr(C)]pub struct TypedBox3D<T, U> {
pub min: TypedPoint3D<T, U>,
pub max: TypedPoint3D<T, U>,
}Expand description
An axis aligned 3D box represented by its minimum and maximum coordinates.
Fields
min: TypedPoint3D<T, U>max: TypedPoint3D<T, U>Implementations
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourcepub fn new(min: TypedPoint3D<T, U>, max: TypedPoint3D<T, U>) -> Self
pub fn new(min: TypedPoint3D<T, U>, max: TypedPoint3D<T, U>) -> Self
Constructor.
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>where
T: Copy + PartialOrd,
impl<T, U> TypedBox3D<T, U>where
T: Copy + PartialOrd,
Sourcepub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Returns true if the box has a negative volume.
The common interpretation for a negative box is to consider it empty. It can be obtained by calculating the intersection of two boxes that do not intersect.
Sourcepub fn is_empty_or_negative(&self) -> bool
pub fn is_empty_or_negative(&self) -> bool
Returns true if the size is zero or negative.
pub fn intersects(&self, other: &Self) -> bool
pub fn try_intersection(&self, other: &Self) -> Option<Self>
pub fn intersection(&self, other: &Self) -> Self
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourcepub fn translate(&self, by: &TypedVector3D<T, U>) -> Self
pub fn translate(&self, by: &TypedVector3D<T, U>) -> Self
Returns the same box3d, translated by a vector.
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourcepub fn contains(&self, other: &TypedPoint3D<T, U>) -> bool
pub fn contains(&self, other: &TypedPoint3D<T, U>) -> bool
Returns true if this box3d contains the point. Points are considered in the box3d if they are on the front, left or top faces, but outside if they are on the back, right or bottom faces.
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourcepub fn contains_box(&self, other: &Self) -> bool
pub fn contains_box(&self, other: &Self) -> bool
Returns true if this box3d contains the interior of the other box3d. Always returns true if other is empty, and always returns false if other is nonempty but this box3d is empty.
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourcepub fn from_points<I>(points: I) -> Self
pub fn from_points<I>(points: I) -> Self
Returns the smallest box containing all of the provided points.
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
pub fn center(&self) -> TypedPoint3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>where
T: Copy,
impl<T, U> TypedBox3D<T, U>where
T: Copy,
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T, U> TypedBox3D<T, U>where
T: PartialEq,
impl<T, U> TypedBox3D<T, U>where
T: PartialEq,
Sourceimpl<T, Unit> TypedBox3D<T, Unit>where
T: Copy,
impl<T, Unit> TypedBox3D<T, Unit>where
T: Copy,
Sourcepub fn to_untyped(&self) -> Box3D<T>
pub fn to_untyped(&self) -> Box3D<T>
Drop the units, preserving only the numeric value.
Sourcepub fn from_untyped(c: &Box3D<T>) -> TypedBox3D<T, Unit>
pub fn from_untyped(c: &Box3D<T>) -> TypedBox3D<T, Unit>
Tag a unitless value with units.
Sourceimpl<T0, Unit> TypedBox3D<T0, Unit>
impl<T0, Unit> TypedBox3D<T0, Unit>
Sourcepub fn cast<T1: NumCast + Copy>(&self) -> TypedBox3D<T1, Unit>
pub fn cast<T1: NumCast + Copy>(&self) -> TypedBox3D<T1, Unit>
Cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated as one would expect from a simple cast, but this behavior does not always make sense geometrically. Consider using round(), round_in or round_out() before casting.
Sourcepub fn try_cast<T1: NumCast + Copy>(&self) -> Option<TypedBox3D<T1, Unit>>
pub fn try_cast<T1: NumCast + Copy>(&self) -> Option<TypedBox3D<T1, Unit>>
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated as one would expect from a simple cast, but this behavior does not always make sense geometrically. Consider using round(), round_in or round_out() before casting.
Sourceimpl<T, U> TypedBox3D<T, U>where
T: Round,
impl<T, U> TypedBox3D<T, U>where
T: Round,
Sourcepub fn round(&self) -> Self
pub fn round(&self) -> Self
Return a box3d with edges rounded to integer coordinates, such that the returned box3d has the same set of pixel centers as the original one. Values equal to 0.5 round up. Suitable for most places where integral device coordinates are needed, but note that any translation should be applied first to avoid pixel rounding errors. Note that this is not rounding to nearest integer if the values are negative. They are always rounding as floor(n + 0.5).
Sourceimpl<T, U> TypedBox3D<T, U>
impl<T, U> TypedBox3D<T, U>
Sourceimpl<T: NumCast + Copy, Unit> TypedBox3D<T, Unit>
impl<T: NumCast + Copy, Unit> TypedBox3D<T, Unit>
Sourcepub fn to_f32(&self) -> TypedBox3D<f32, Unit>
pub fn to_f32(&self) -> TypedBox3D<f32, Unit>
Cast into an f32 box3d.
Sourcepub fn to_f64(&self) -> TypedBox3D<f64, Unit>
pub fn to_f64(&self) -> TypedBox3D<f64, Unit>
Cast into an f64 box3d.
Sourcepub fn to_usize(&self) -> TypedBox3D<usize, Unit>
pub fn to_usize(&self) -> TypedBox3D<usize, Unit>
Cast into an usize box3d, truncating decimals if any.
When casting from floating point cuboids, it is worth considering whether
to round(), round_in() or round_out() before the cast in order to
obtain the desired conversion behavior.
Sourcepub fn to_u32(&self) -> TypedBox3D<u32, Unit>
pub fn to_u32(&self) -> TypedBox3D<u32, Unit>
Cast into an u32 box3d, truncating decimals if any.
When casting from floating point cuboids, it is worth considering whether
to round(), round_in() or round_out() before the cast in order to
obtain the desired conversion behavior.
Sourcepub fn to_i32(&self) -> TypedBox3D<i32, Unit>
pub fn to_i32(&self) -> TypedBox3D<i32, Unit>
Cast into an i32 box3d, truncating decimals if any.
When casting from floating point cuboids, it is worth considering whether
to round(), round_in() or round_out() before the cast in order to
obtain the desired conversion behavior.
Sourcepub fn to_i64(&self) -> TypedBox3D<i64, Unit>
pub fn to_i64(&self) -> TypedBox3D<i64, Unit>
Cast into an i64 box3d, truncating decimals if any.
When casting from floating point cuboids, it is worth considering whether
to round(), round_in() or round_out() before the cast in order to
obtain the desired conversion behavior.