#[repr(C)]pub struct TypedPoint2D<T, U> {
pub x: T,
pub y: T,
/* private fields */
}Expand description
A 2d Point tagged with a unit.
Fields
x: Ty: TImplementations
Sourceimpl<T: Copy + Zero, U> TypedPoint2D<T, U>
impl<T: Copy + Zero, U> TypedPoint2D<T, U>
Sourceimpl<T, U> TypedPoint2D<T, U>
impl<T, U> TypedPoint2D<T, U>
Sourceimpl<T: Copy, U> TypedPoint2D<T, U>
impl<T: Copy, U> TypedPoint2D<T, U>
Sourcepub fn from_lengths(x: Length<T, U>, y: Length<T, U>) -> Self
pub fn from_lengths(x: Length<T, U>, y: Length<T, U>) -> Self
Constructor taking properly typed Lengths instead of scalar values.
Sourcepub fn extend(&self, z: T) -> TypedPoint3D<T, U>
pub fn extend(&self, z: T) -> TypedPoint3D<T, U>
Create a 3d point from this one, using the specified z value.
Sourcepub fn to_vector(&self) -> TypedVector2D<T, U>
pub fn to_vector(&self) -> TypedVector2D<T, U>
Cast this point into a vector.
Equivalent to subtracting the origin from this point.
Sourcepub fn to_untyped(&self) -> Point2D<T>
pub fn to_untyped(&self) -> Point2D<T>
Drop the units, preserving only the numeric value.
Sourcepub fn from_untyped(p: &Point2D<T>) -> Self
pub fn from_untyped(p: &Point2D<T>) -> Self
Tag a unitless value with units.
pub fn to_array(&self) -> [T; 2]
pub fn to_tuple(&self) -> (T, T)
Sourceimpl<T: Copy + Add<T, Output = T>, U> TypedPoint2D<T, U>
impl<T: Copy + Add<T, Output = T>, U> TypedPoint2D<T, U>
pub fn add_size(&self, other: &TypedSize2D<T, U>) -> Self
Sourceimpl<T: Float, U> TypedPoint2D<T, U>
impl<T: Float, U> TypedPoint2D<T, U>
Sourceimpl<T: Round, U> TypedPoint2D<T, U>
impl<T: Round, U> TypedPoint2D<T, U>
Sourceimpl<T: Ceil, U> TypedPoint2D<T, U>
impl<T: Ceil, U> TypedPoint2D<T, U>
Sourceimpl<T: Floor, U> TypedPoint2D<T, U>
impl<T: Floor, U> TypedPoint2D<T, U>
Sourceimpl<T: NumCast + Copy, U> TypedPoint2D<T, U>
impl<T: NumCast + Copy, U> TypedPoint2D<T, U>
Sourcepub fn cast<NewT: NumCast + Copy>(&self) -> TypedPoint2D<NewT, U>
pub fn cast<NewT: NumCast + Copy>(&self) -> TypedPoint2D<NewT, U>
Cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedPoint2D<NewT, U>>
pub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedPoint2D<NewT, U>>
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn to_f32(&self) -> TypedPoint2D<f32, U>
pub fn to_f32(&self) -> TypedPoint2D<f32, U>
Cast into an f32 point.
Sourcepub fn to_f64(&self) -> TypedPoint2D<f64, U>
pub fn to_f64(&self) -> TypedPoint2D<f64, U>
Cast into an f64 point.
Sourcepub fn to_usize(&self) -> TypedPoint2D<usize, U>
pub fn to_usize(&self) -> TypedPoint2D<usize, U>
Cast into an usize point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_u32(&self) -> TypedPoint2D<u32, U>
pub fn to_u32(&self) -> TypedPoint2D<u32, U>
Cast into an u32 point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i32(&self) -> TypedPoint2D<i32, U>
pub fn to_i32(&self) -> TypedPoint2D<i32, U>
Cast into an i32 point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i64(&self) -> TypedPoint2D<i64, U>
pub fn to_i64(&self) -> TypedPoint2D<i64, U>
Cast into an i64 point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.