#[repr(C)]pub struct TypedPoint3D<T, U> {
pub x: T,
pub y: T,
pub z: T,
/* private fields */
}Expand description
A 3d Point tagged with a unit.
Fields
x: Ty: Tz: TImplementations
Sourceimpl<T: Copy + Zero, U> TypedPoint3D<T, U>
impl<T: Copy + Zero, U> TypedPoint3D<T, U>
Sourceimpl<T: Copy + One, U> TypedPoint3D<T, U>
impl<T: Copy + One, U> TypedPoint3D<T, U>
pub fn to_array_4d(&self) -> [T; 4]
pub fn to_tuple_4d(&self) -> (T, T, T, T)
Sourceimpl<T, U> TypedPoint3D<T, U>
impl<T, U> TypedPoint3D<T, U>
Sourceimpl<T: Copy, U> TypedPoint3D<T, U>
impl<T: Copy, U> TypedPoint3D<T, U>
Sourcepub fn from_lengths(x: Length<T, U>, y: Length<T, U>, z: Length<T, U>) -> Self
pub fn from_lengths(x: Length<T, U>, y: Length<T, U>, z: Length<T, U>) -> Self
Constructor taking properly typed Lengths instead of scalar values.
Sourcepub fn to_vector(&self) -> TypedVector3D<T, U>
pub fn to_vector(&self) -> TypedVector3D<T, U>
Cast this point into a vector.
Equivalent to subtracting the origin to this point.
Sourcepub fn xy(&self) -> TypedPoint2D<T, U>
pub fn xy(&self) -> TypedPoint2D<T, U>
Returns a 2d point using this point’s x and y coordinates
Sourcepub fn xz(&self) -> TypedPoint2D<T, U>
pub fn xz(&self) -> TypedPoint2D<T, U>
Returns a 2d point using this point’s x and z coordinates
Sourcepub fn yz(&self) -> TypedPoint2D<T, U>
pub fn yz(&self) -> TypedPoint2D<T, U>
Returns a 2d point using this point’s x and z coordinates
pub fn to_array(&self) -> [T; 3]
pub fn to_tuple(&self) -> (T, T, T)
Sourcepub fn to_untyped(&self) -> Point3D<T>
pub fn to_untyped(&self) -> Point3D<T>
Drop the units, preserving only the numeric value.
Sourcepub fn from_untyped(p: &Point3D<T>) -> Self
pub fn from_untyped(p: &Point3D<T>) -> Self
Tag a unitless value with units.
Sourcepub fn to_2d(&self) -> TypedPoint2D<T, U>
pub fn to_2d(&self) -> TypedPoint2D<T, U>
Convert into a 2d point.
Sourceimpl<T: Copy + Add<T, Output = T>, U> TypedPoint3D<T, U>
impl<T: Copy + Add<T, Output = T>, U> TypedPoint3D<T, U>
Sourceimpl<T: Float, U> TypedPoint3D<T, U>
impl<T: Float, U> TypedPoint3D<T, U>
Sourceimpl<T: Round, U> TypedPoint3D<T, U>
impl<T: Round, U> TypedPoint3D<T, U>
Sourceimpl<T: Ceil, U> TypedPoint3D<T, U>
impl<T: Ceil, U> TypedPoint3D<T, U>
Sourceimpl<T: Floor, U> TypedPoint3D<T, U>
impl<T: Floor, U> TypedPoint3D<T, U>
Sourceimpl<T: NumCast + Copy, U> TypedPoint3D<T, U>
impl<T: NumCast + Copy, U> TypedPoint3D<T, U>
Sourcepub fn cast<NewT: NumCast + Copy>(&self) -> TypedPoint3D<NewT, U>
pub fn cast<NewT: NumCast + Copy>(&self) -> TypedPoint3D<NewT, U>
Cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedPoint3D<NewT, U>>
pub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedPoint3D<NewT, U>>
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn to_f32(&self) -> TypedPoint3D<f32, U>
pub fn to_f32(&self) -> TypedPoint3D<f32, U>
Cast into an f32 point.
Sourcepub fn to_f64(&self) -> TypedPoint3D<f64, U>
pub fn to_f64(&self) -> TypedPoint3D<f64, U>
Cast into an f64 point.
Sourcepub fn to_usize(&self) -> TypedPoint3D<usize, U>
pub fn to_usize(&self) -> TypedPoint3D<usize, U>
Cast into an usize point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_u32(&self) -> TypedPoint3D<u32, U>
pub fn to_u32(&self) -> TypedPoint3D<u32, U>
Cast into an u32 point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i32(&self) -> TypedPoint3D<i32, U>
pub fn to_i32(&self) -> TypedPoint3D<i32, U>
Cast into an i32 point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i64(&self) -> TypedPoint3D<i64, U>
pub fn to_i64(&self) -> TypedPoint3D<i64, U>
Cast into an i64 point, truncating decimals if any.
When casting from floating point points, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.