Struct TypedRotation2D

#[repr(C)]
pub struct TypedRotation2D<T, Src, Dst> { pub angle: T, /* private fields */ }
A transform that can represent rotations in 2d, represented as an angle in radians.

Fields

angle: T

Implementations

Source

impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>

pub fn new(angle: Angle<T>) -> Self

Creates a rotation from an angle in radians.

pub fn radians(angle: T) -> Self

pub fn identity() -> Self
where T: Zero,

Creates the identity rotation.

Source

impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
where T: Clone,

pub fn get_angle(&self) -> Angle<T>

Returns self.angle as a strongly typed Angle<T>.

Source

impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
where T: Copy + Clone + Add<T, Output = T> + Sub<T, Output = T> + Mul<T, Output = T> + Div<T, Output = T> + Neg<Output = T> + PartialOrd + Float + One + Zero,

pub fn to_3d(&self) -> TypedRotation3D<T, Src, Dst>

Creates a 3d rotation (around the z axis) from this 2d rotation.

pub fn inverse(&self) -> TypedRotation2D<T, Dst, Src>

Returns the inverse of this rotation.

pub fn pre_rotate<NewSrc>( &self, other: &TypedRotation2D<T, NewSrc, Src>, ) -> TypedRotation2D<T, NewSrc, Dst>

Returns a rotation representing the other rotation followed by this rotation.

pub fn post_rotate<NewDst>( &self, other: &TypedRotation2D<T, Dst, NewDst>, ) -> TypedRotation2D<T, Src, NewDst>

Returns a rotation representing this rotation followed by the other rotation.

pub fn transform_point( &self, point: &TypedPoint2D<T, Src>, ) -> TypedPoint2D<T, Dst>

Returns the given 2d point transformed by this rotation.

The input point must be use the unit Src, and the returned point has the unit Dst.

pub fn transform_vector( &self, vector: &TypedVector2D<T, Src>, ) -> TypedVector2D<T, Dst>

Returns the given 2d vector transformed by this rotation.

The input point must be use the unit Src, and the returned point has the unit Dst.

Source

impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
where T: Copy + Clone + Add<T, Output = T> + Mul<T, Output = T> + Div<T, Output = T> + Sub<T, Output = T> + Trig + PartialOrd + One + Zero,

pub fn to_transform(&self) -> TypedTransform2D<T, Src, Dst>

Returns the matrix representation of this rotation.