Struct TypedSideOffsets2D

#[repr(C)]
pub struct TypedSideOffsets2D<T, U> { pub top: T, pub right: T, pub bottom: T, pub left: T, /* private fields */ }
A group of 2D side offsets, which correspond to top/left/bottom/right for borders, padding, and margins in CSS, optionally tagged with a unit.

Fields

top: Tright: Tbottom: Tleft: T

Implementations

Source

impl<T: Copy, U> TypedSideOffsets2D<T, U>

pub fn new(top: T, right: T, bottom: T, left: T) -> Self

Constructor taking a scalar for each side.

pub fn from_lengths( top: Length<T, U>, right: Length<T, U>, bottom: Length<T, U>, left: Length<T, U>, ) -> Self

Constructor taking a typed Length for each side.

pub fn top_typed(&self) -> Length<T, U>

Access self.top as a typed Length instead of a scalar value.

pub fn right_typed(&self) -> Length<T, U>

Access self.right as a typed Length instead of a scalar value.

pub fn bottom_typed(&self) -> Length<T, U>

Access self.bottom as a typed Length instead of a scalar value.

pub fn left_typed(&self) -> Length<T, U>

Access self.left as a typed Length instead of a scalar value.

pub fn new_all_same(all: T) -> Self

Constructor setting the same value to all sides, taking a scalar value directly.

pub fn from_length_all_same(all: Length<T, U>) -> Self

Constructor setting the same value to all sides, taking a typed Length.

Source

impl<T, U> TypedSideOffsets2D<T, U>
where T: Add<T, Output = T> + Copy,

pub fn horizontal(&self) -> T

pub fn vertical(&self) -> T

pub fn horizontal_typed(&self) -> Length<T, U>

pub fn vertical_typed(&self) -> Length<T, U>

Source

impl<T: Copy + Zero, U> TypedSideOffsets2D<T, U>

pub fn zero() -> Self

Constructor, setting all sides to zero.