Struct TypedSize2D

#[repr(C)]
pub struct TypedSize2D<T, U> { pub width: T, pub height: T, /* private fields */ }
A 2d size tagged with a unit.

Fields

width: Theight: T

Implementations

Source

impl<T, U> TypedSize2D<T, U>

pub fn new(width: T, height: T) -> Self

Constructor taking scalar values.

Source

impl<T: Clone, U> TypedSize2D<T, U>

pub fn from_lengths(width: Length<T, U>, height: Length<T, U>) -> Self

Constructor taking scalar strongly typed lengths.

Source

impl<T: Round, U> TypedSize2D<T, U>

pub fn round(&self) -> Self

Rounds each component to the nearest integer value.

This behavior is preserved for negative values (unlike the basic cast).

Source

impl<T: Ceil, U> TypedSize2D<T, U>

pub fn ceil(&self) -> Self

Rounds each component to the smallest integer equal or greater than the original value.

This behavior is preserved for negative values (unlike the basic cast).

Source

impl<T: Floor, U> TypedSize2D<T, U>

pub fn floor(&self) -> Self

Rounds each component to the biggest integer equal or lower than the original value.

This behavior is preserved for negative values (unlike the basic cast).

Source

impl<T: Copy + Clone + Mul<T>, U> TypedSize2D<T, U>

pub fn area(&self) -> T::Output

Source

impl<T, U> TypedSize2D<T, U>
where T: Copy + One + Add<Output = T> + Sub<Output = T> + Mul<Output = T>,

pub fn lerp(&self, other: Self, t: T) -> Self

Linearly interpolate between this size and another size.

t is expected to be between zero and one.

Source

impl<T: Zero + PartialOrd, U> TypedSize2D<T, U>

Source

impl<T: Zero, U> TypedSize2D<T, U>

pub fn zero() -> Self

Source

impl<T: Copy, U> TypedSize2D<T, U>

pub fn width_typed(&self) -> Length<T, U>

Returns self.width as a Length carrying the unit.

pub fn height_typed(&self) -> Length<T, U>

Returns self.height as a Length carrying the unit.

pub fn to_array(&self) -> [T; 2]

pub fn to_tuple(&self) -> (T, T)

pub fn to_vector(&self) -> TypedVector2D<T, U>

pub fn to_untyped(&self) -> Size2D<T>

Drop the units, preserving only the numeric value.

pub fn from_untyped(p: &Size2D<T>) -> Self

Tag a unitless value with units.

Source

impl<T: NumCast + Copy, Unit> TypedSize2D<T, Unit>

pub fn cast<NewT: NumCast + Copy>(&self) -> TypedSize2D<NewT, Unit>

Cast from one numeric representation to another, preserving the units.

When casting from floating point to integer coordinates, the decimals are truncated as one would expect from a simple cast, but this behavior does not always make sense geometrically. Consider using round(), ceil() or floor() before casting.

pub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedSize2D<NewT, Unit>>

Fallible cast from one numeric representation to another, preserving the units.

When casting from floating point to integer coordinates, the decimals are truncated as one would expect from a simple cast, but this behavior does not always make sense geometrically. Consider using round(), ceil() or floor() before casting.

pub fn to_f32(&self) -> TypedSize2D<f32, Unit>

Cast into an f32 size.

pub fn to_f64(&self) -> TypedSize2D<f64, Unit>

Cast into an f64 size.

pub fn to_usize(&self) -> TypedSize2D<usize, Unit>

Cast into an uint size, truncating decimals if any.

When casting from floating point sizes, it is worth considering whether to round(), ceil() or floor() before the cast in order to obtain the desired conversion behavior.

pub fn to_u32(&self) -> TypedSize2D<u32, Unit>

Cast into an u32 size, truncating decimals if any.

When casting from floating point sizes, it is worth considering whether to round(), ceil() or floor() before the cast in order to obtain the desired conversion behavior.

pub fn to_i32(&self) -> TypedSize2D<i32, Unit>

Cast into an i32 size, truncating decimals if any.

When casting from floating point sizes, it is worth considering whether to round(), ceil() or floor() before the cast in order to obtain the desired conversion behavior.

pub fn to_i64(&self) -> TypedSize2D<i64, Unit>

Cast into an i64 size, truncating decimals if any.

When casting from floating point sizes, it is worth considering whether to round(), ceil() or floor() before the cast in order to obtain the desired conversion behavior.

Source

impl<T, U> TypedSize2D<T, U>
where T: Signed,

pub fn abs(&self) -> Self

pub fn is_positive(&self) -> bool

Source

impl<T: PartialOrd, U> TypedSize2D<T, U>

pub fn greater_than(&self, other: &Self) -> BoolVector2D

pub fn lower_than(&self, other: &Self) -> BoolVector2D

Source

impl<T: PartialEq, U> TypedSize2D<T, U>

pub fn equal(&self, other: &Self) -> BoolVector2D

pub fn not_equal(&self, other: &Self) -> BoolVector2D

Source

impl<T: Float, U> TypedSize2D<T, U>

pub fn min(self, other: Self) -> Self

pub fn max(self, other: Self) -> Self

pub fn clamp(&self, start: Self, end: Self) -> Self