#[repr(C)]pub struct TypedVector2D<T, U> {
pub x: T,
pub y: T,
/* private fields */
}Expand description
A 2d Vector tagged with a unit.
Fields
x: Ty: TImplementations
Sourceimpl<T: Copy + Zero, U> TypedVector2D<T, U>
impl<T: Copy + Zero, U> TypedVector2D<T, U>
Sourcepub fn to_3d(&self) -> TypedVector3D<T, U>
pub fn to_3d(&self) -> TypedVector3D<T, U>
Convert into a 3d vector.
Sourceimpl<T, U> TypedVector2D<T, U>
impl<T, U> TypedVector2D<T, U>
Sourceimpl<T: Copy, U> TypedVector2D<T, U>
impl<T: Copy, U> TypedVector2D<T, U>
Sourcepub fn from_lengths(x: Length<T, U>, y: Length<T, U>) -> Self
pub fn from_lengths(x: Length<T, U>, y: Length<T, U>) -> Self
Constructor taking properly typed Lengths instead of scalar values.
Sourcepub fn extend(&self, z: T) -> TypedVector3D<T, U>
pub fn extend(&self, z: T) -> TypedVector3D<T, U>
Create a 3d vector from this one, using the specified z value.
Sourcepub fn to_point(&self) -> TypedPoint2D<T, U>
pub fn to_point(&self) -> TypedPoint2D<T, U>
Cast this vector into a point.
Equivalent to adding this vector to the origin.
Sourcepub fn to_size(&self) -> TypedSize2D<T, U>
pub fn to_size(&self) -> TypedSize2D<T, U>
Cast this vector into a size.
Sourcepub fn to_untyped(&self) -> Vector2D<T>
pub fn to_untyped(&self) -> Vector2D<T>
Drop the units, preserving only the numeric value.
Sourcepub fn from_untyped(p: &Vector2D<T>) -> Self
pub fn from_untyped(p: &Vector2D<T>) -> Self
Tag a unit-less value with units.
Sourcepub fn cast_unit<V>(&self) -> TypedVector2D<T, V>
pub fn cast_unit<V>(&self) -> TypedVector2D<T, V>
Cast the unit
pub fn to_array(&self) -> [T; 2]
pub fn to_tuple(&self) -> (T, T)
Sourceimpl<T, U> TypedVector2D<T, U>
impl<T, U> TypedVector2D<T, U>
pub fn to_transform(&self) -> TypedTransform2D<T, U, U>
Sourceimpl<T, U> TypedVector2D<T, U>
impl<T, U> TypedVector2D<T, U>
Sourcepub fn angle_from_x_axis(&self) -> Angle<T>
pub fn angle_from_x_axis(&self) -> Angle<T>
Returns the angle between this vector and the x axis between -PI and PI.
Sourceimpl<T, U> TypedVector2D<T, U>
impl<T, U> TypedVector2D<T, U>
Sourcepub fn cross(self, other: Self) -> T
pub fn cross(self, other: Self) -> T
Returns the norm of the cross product [self.x, self.y, 0] x [other.x, other.y, 0]..
pub fn normalize(self) -> Selfwhere
T: Float,
Sourcepub fn robust_normalize(self) -> Selfwhere
T: Float,
pub fn robust_normalize(self) -> Selfwhere
T: Float,
Return the normalized vector even if the length is larger than the max value of Float.
pub fn square_length(&self) -> T
pub fn length(&self) -> Twhere
T: Float,
Sourceimpl<T, U> TypedVector2D<T, U>
impl<T, U> TypedVector2D<T, U>
Sourceimpl<T: Float, U> TypedVector2D<T, U>
impl<T: Float, U> TypedVector2D<T, U>
Sourceimpl<T: Round, U> TypedVector2D<T, U>
impl<T: Round, U> TypedVector2D<T, U>
Sourceimpl<T: Ceil, U> TypedVector2D<T, U>
impl<T: Ceil, U> TypedVector2D<T, U>
Sourceimpl<T: Floor, U> TypedVector2D<T, U>
impl<T: Floor, U> TypedVector2D<T, U>
Sourceimpl<T: NumCast + Copy, U> TypedVector2D<T, U>
impl<T: NumCast + Copy, U> TypedVector2D<T, U>
Sourcepub fn cast<NewT: NumCast + Copy>(&self) -> TypedVector2D<NewT, U>
pub fn cast<NewT: NumCast + Copy>(&self) -> TypedVector2D<NewT, U>
Cast from one numeric representation to another, preserving the units.
When casting from floating vector to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedVector2D<NewT, U>>
pub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedVector2D<NewT, U>>
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating vector to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn to_f32(&self) -> TypedVector2D<f32, U>
pub fn to_f32(&self) -> TypedVector2D<f32, U>
Cast into an f32 vector.
Sourcepub fn to_f64(&self) -> TypedVector2D<f64, U>
pub fn to_f64(&self) -> TypedVector2D<f64, U>
Cast into an f64 vector.
Sourcepub fn to_usize(&self) -> TypedVector2D<usize, U>
pub fn to_usize(&self) -> TypedVector2D<usize, U>
Cast into an usize vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_u32(&self) -> TypedVector2D<u32, U>
pub fn to_u32(&self) -> TypedVector2D<u32, U>
Cast into an u32 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i32(&self) -> TypedVector2D<i32, U>
pub fn to_i32(&self) -> TypedVector2D<i32, U>
Cast into an i32 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i64(&self) -> TypedVector2D<i64, U>
pub fn to_i64(&self) -> TypedVector2D<i64, U>
Cast into an i64 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourceimpl<T: PartialOrd, U> TypedVector2D<T, U>
impl<T: PartialOrd, U> TypedVector2D<T, U>
pub fn greater_than(&self, other: &Self) -> BoolVector2D
pub fn lower_than(&self, other: &Self) -> BoolVector2D
Sourceimpl<T: PartialEq, U> TypedVector2D<T, U>
impl<T: PartialEq, U> TypedVector2D<T, U>
pub fn equal(&self, other: &Self) -> BoolVector2D
pub fn not_equal(&self, other: &Self) -> BoolVector2D