#[repr(C)]pub struct TypedVector3D<T, U> {
pub x: T,
pub y: T,
pub z: T,
/* private fields */
}Expand description
A 3d Vector tagged with a unit.
Fields
x: Ty: Tz: TImplementations
Sourceimpl<T: Copy + Zero, U> TypedVector3D<T, U>
impl<T: Copy + Zero, U> TypedVector3D<T, U>
pub fn to_array_4d(&self) -> [T; 4]
pub fn to_tuple_4d(&self) -> (T, T, T, T)
Sourceimpl<T, U> TypedVector3D<T, U>
impl<T, U> TypedVector3D<T, U>
Sourceimpl<T: Copy, U> TypedVector3D<T, U>
impl<T: Copy, U> TypedVector3D<T, U>
Sourcepub fn from_lengths(
x: Length<T, U>,
y: Length<T, U>,
z: Length<T, U>,
) -> TypedVector3D<T, U>
pub fn from_lengths( x: Length<T, U>, y: Length<T, U>, z: Length<T, U>, ) -> TypedVector3D<T, U>
Constructor taking properly typed Lengths instead of scalar values.
Sourcepub fn to_point(&self) -> TypedPoint3D<T, U>
pub fn to_point(&self) -> TypedPoint3D<T, U>
Cast this vector into a point.
Equivalent to adding this vector to the origin.
Sourcepub fn xy(&self) -> TypedVector2D<T, U>
pub fn xy(&self) -> TypedVector2D<T, U>
Returns a 2d vector using this vector’s x and y coordinates
Sourcepub fn xz(&self) -> TypedVector2D<T, U>
pub fn xz(&self) -> TypedVector2D<T, U>
Returns a 2d vector using this vector’s x and z coordinates
Sourcepub fn yz(&self) -> TypedVector2D<T, U>
pub fn yz(&self) -> TypedVector2D<T, U>
Returns a 2d vector using this vector’s x and z coordinates
pub fn to_array(&self) -> [T; 3]
pub fn to_tuple(&self) -> (T, T, T)
Sourcepub fn to_untyped(&self) -> Vector3D<T>
pub fn to_untyped(&self) -> Vector3D<T>
Drop the units, preserving only the numeric value.
Sourcepub fn from_untyped(p: &Vector3D<T>) -> Self
pub fn from_untyped(p: &Vector3D<T>) -> Self
Tag a unitless value with units.
Sourcepub fn to_2d(&self) -> TypedVector2D<T, U>
pub fn to_2d(&self) -> TypedVector2D<T, U>
Convert into a 2d vector.
Sourceimpl<T, U> TypedVector3D<T, U>
impl<T, U> TypedVector3D<T, U>
pub fn to_transform(&self) -> TypedTransform3D<T, U, U>
Sourceimpl<T: Mul<T, Output = T> + Add<T, Output = T> + Sub<T, Output = T> + Copy, U> TypedVector3D<T, U>
impl<T: Mul<T, Output = T> + Add<T, Output = T> + Sub<T, Output = T> + Copy, U> TypedVector3D<T, U>
pub fn dot(self, other: Self) -> T
pub fn cross(self, other: Self) -> Self
pub fn normalize(self) -> Selfwhere
T: Float,
Sourcepub fn robust_normalize(self) -> Selfwhere
T: Float,
pub fn robust_normalize(self) -> Selfwhere
T: Float,
Return the normalized vector even if the length is larger than the max value of Float.
pub fn square_length(&self) -> T
pub fn length(&self) -> Twhere
T: Float,
Sourceimpl<T, U> TypedVector3D<T, U>
impl<T, U> TypedVector3D<T, U>
Sourceimpl<T: Float, U> TypedVector3D<T, U>
impl<T: Float, U> TypedVector3D<T, U>
Sourceimpl<T: Round, U> TypedVector3D<T, U>
impl<T: Round, U> TypedVector3D<T, U>
Sourceimpl<T: Ceil, U> TypedVector3D<T, U>
impl<T: Ceil, U> TypedVector3D<T, U>
Sourceimpl<T: Floor, U> TypedVector3D<T, U>
impl<T: Floor, U> TypedVector3D<T, U>
Sourceimpl<T: NumCast + Copy, U> TypedVector3D<T, U>
impl<T: NumCast + Copy, U> TypedVector3D<T, U>
Sourcepub fn cast<NewT: NumCast + Copy>(&self) -> TypedVector3D<NewT, U>
pub fn cast<NewT: NumCast + Copy>(&self) -> TypedVector3D<NewT, U>
Cast from one numeric representation to another, preserving the units.
When casting from floating vector to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedVector3D<NewT, U>>
pub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedVector3D<NewT, U>>
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating vector to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn to_f32(&self) -> TypedVector3D<f32, U>
pub fn to_f32(&self) -> TypedVector3D<f32, U>
Cast into an f32 vector.
Sourcepub fn to_f64(&self) -> TypedVector3D<f64, U>
pub fn to_f64(&self) -> TypedVector3D<f64, U>
Cast into an f64 vector.
Sourcepub fn to_usize(&self) -> TypedVector3D<usize, U>
pub fn to_usize(&self) -> TypedVector3D<usize, U>
Cast into an usize vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_u32(&self) -> TypedVector3D<u32, U>
pub fn to_u32(&self) -> TypedVector3D<u32, U>
Cast into an u32 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i32(&self) -> TypedVector3D<i32, U>
pub fn to_i32(&self) -> TypedVector3D<i32, U>
Cast into an i32 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i64(&self) -> TypedVector3D<i64, U>
pub fn to_i64(&self) -> TypedVector3D<i64, U>
Cast into an i64 vector, truncating decimals if any.
When casting from floating vector vectors, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourceimpl<T: PartialOrd, U> TypedVector3D<T, U>
impl<T: PartialOrd, U> TypedVector3D<T, U>
pub fn greater_than(&self, other: &Self) -> BoolVector3D
pub fn lower_than(&self, other: &Self) -> BoolVector3D
Sourceimpl<T: PartialEq, U> TypedVector3D<T, U>
impl<T: PartialEq, U> TypedVector3D<T, U>
pub fn equal(&self, other: &Self) -> BoolVector3D
pub fn not_equal(&self, other: &Self) -> BoolVector3D