#[repr(C)]pub struct TypedRotation2D<T, Src, Dst> {
pub angle: T,
/* private fields */
}Expand description
A transform that can represent rotations in 2d, represented as an angle in radians.
Fields
angle: TImplementations
Sourceimpl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
Sourceimpl<T, Src, Dst> TypedRotation2D<T, Src, Dst>where
T: Clone,
impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>where
T: Clone,
Sourceimpl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
Sourcepub fn to_3d(&self) -> TypedRotation3D<T, Src, Dst>
pub fn to_3d(&self) -> TypedRotation3D<T, Src, Dst>
Creates a 3d rotation (around the z axis) from this 2d rotation.
Sourcepub fn inverse(&self) -> TypedRotation2D<T, Dst, Src>
pub fn inverse(&self) -> TypedRotation2D<T, Dst, Src>
Returns the inverse of this rotation.
Sourcepub fn pre_rotate<NewSrc>(
&self,
other: &TypedRotation2D<T, NewSrc, Src>,
) -> TypedRotation2D<T, NewSrc, Dst>
pub fn pre_rotate<NewSrc>( &self, other: &TypedRotation2D<T, NewSrc, Src>, ) -> TypedRotation2D<T, NewSrc, Dst>
Returns a rotation representing the other rotation followed by this rotation.
Sourcepub fn post_rotate<NewDst>(
&self,
other: &TypedRotation2D<T, Dst, NewDst>,
) -> TypedRotation2D<T, Src, NewDst>
pub fn post_rotate<NewDst>( &self, other: &TypedRotation2D<T, Dst, NewDst>, ) -> TypedRotation2D<T, Src, NewDst>
Returns a rotation representing this rotation followed by the other rotation.
Sourcepub fn transform_point(
&self,
point: &TypedPoint2D<T, Src>,
) -> TypedPoint2D<T, Dst>
pub fn transform_point( &self, point: &TypedPoint2D<T, Src>, ) -> TypedPoint2D<T, Dst>
Returns the given 2d point transformed by this rotation.
The input point must be use the unit Src, and the returned point has the unit Dst.
Sourcepub fn transform_vector(
&self,
vector: &TypedVector2D<T, Src>,
) -> TypedVector2D<T, Dst>
pub fn transform_vector( &self, vector: &TypedVector2D<T, Src>, ) -> TypedVector2D<T, Dst>
Returns the given 2d vector transformed by this rotation.
The input point must be use the unit Src, and the returned point has the unit Dst.
Sourceimpl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
impl<T, Src, Dst> TypedRotation2D<T, Src, Dst>
Sourcepub fn to_transform(&self) -> TypedTransform2D<T, Src, Dst>
pub fn to_transform(&self) -> TypedTransform2D<T, Src, Dst>
Returns the matrix representation of this rotation.