#[repr(C)]pub struct TypedSize2D<T, U> {
pub width: T,
pub height: T,
/* private fields */
}Expand description
A 2d size tagged with a unit.
Fields
width: Theight: TImplementations
Sourceimpl<T, U> TypedSize2D<T, U>
impl<T, U> TypedSize2D<T, U>
Sourceimpl<T: Clone, U> TypedSize2D<T, U>
impl<T: Clone, U> TypedSize2D<T, U>
Sourcepub fn from_lengths(width: Length<T, U>, height: Length<T, U>) -> Self
pub fn from_lengths(width: Length<T, U>, height: Length<T, U>) -> Self
Constructor taking scalar strongly typed lengths.
Sourceimpl<T: Round, U> TypedSize2D<T, U>
impl<T: Round, U> TypedSize2D<T, U>
Sourceimpl<T: Ceil, U> TypedSize2D<T, U>
impl<T: Ceil, U> TypedSize2D<T, U>
Sourceimpl<T: Floor, U> TypedSize2D<T, U>
impl<T: Floor, U> TypedSize2D<T, U>
Sourceimpl<T, U> TypedSize2D<T, U>
impl<T, U> TypedSize2D<T, U>
Sourceimpl<T: Zero + PartialOrd, U> TypedSize2D<T, U>
impl<T: Zero + PartialOrd, U> TypedSize2D<T, U>
pub fn is_empty_or_negative(&self) -> bool
Sourceimpl<T: Copy, U> TypedSize2D<T, U>
impl<T: Copy, U> TypedSize2D<T, U>
Sourcepub fn width_typed(&self) -> Length<T, U>
pub fn width_typed(&self) -> Length<T, U>
Returns self.width as a Length carrying the unit.
Sourcepub fn height_typed(&self) -> Length<T, U>
pub fn height_typed(&self) -> Length<T, U>
Returns self.height as a Length carrying the unit.
pub fn to_array(&self) -> [T; 2]
pub fn to_tuple(&self) -> (T, T)
pub fn to_vector(&self) -> TypedVector2D<T, U>
Sourcepub fn to_untyped(&self) -> Size2D<T>
pub fn to_untyped(&self) -> Size2D<T>
Drop the units, preserving only the numeric value.
Sourcepub fn from_untyped(p: &Size2D<T>) -> Self
pub fn from_untyped(p: &Size2D<T>) -> Self
Tag a unitless value with units.
Sourceimpl<T: NumCast + Copy, Unit> TypedSize2D<T, Unit>
impl<T: NumCast + Copy, Unit> TypedSize2D<T, Unit>
Sourcepub fn cast<NewT: NumCast + Copy>(&self) -> TypedSize2D<NewT, Unit>
pub fn cast<NewT: NumCast + Copy>(&self) -> TypedSize2D<NewT, Unit>
Cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedSize2D<NewT, Unit>>
pub fn try_cast<NewT: NumCast + Copy>(&self) -> Option<TypedSize2D<NewT, Unit>>
Fallible cast from one numeric representation to another, preserving the units.
When casting from floating point to integer coordinates, the decimals are truncated
as one would expect from a simple cast, but this behavior does not always make sense
geometrically. Consider using round(), ceil() or floor() before casting.
Sourcepub fn to_f32(&self) -> TypedSize2D<f32, Unit>
pub fn to_f32(&self) -> TypedSize2D<f32, Unit>
Cast into an f32 size.
Sourcepub fn to_f64(&self) -> TypedSize2D<f64, Unit>
pub fn to_f64(&self) -> TypedSize2D<f64, Unit>
Cast into an f64 size.
Sourcepub fn to_usize(&self) -> TypedSize2D<usize, Unit>
pub fn to_usize(&self) -> TypedSize2D<usize, Unit>
Cast into an uint size, truncating decimals if any.
When casting from floating point sizes, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_u32(&self) -> TypedSize2D<u32, Unit>
pub fn to_u32(&self) -> TypedSize2D<u32, Unit>
Cast into an u32 size, truncating decimals if any.
When casting from floating point sizes, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i32(&self) -> TypedSize2D<i32, Unit>
pub fn to_i32(&self) -> TypedSize2D<i32, Unit>
Cast into an i32 size, truncating decimals if any.
When casting from floating point sizes, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourcepub fn to_i64(&self) -> TypedSize2D<i64, Unit>
pub fn to_i64(&self) -> TypedSize2D<i64, Unit>
Cast into an i64 size, truncating decimals if any.
When casting from floating point sizes, it is worth considering whether
to round(), ceil() or floor() before the cast in order to obtain
the desired conversion behavior.
Sourceimpl<T, U> TypedSize2D<T, U>where
T: Signed,
impl<T, U> TypedSize2D<T, U>where
T: Signed,
pub fn abs(&self) -> Self
pub fn is_positive(&self) -> bool
Sourceimpl<T: PartialOrd, U> TypedSize2D<T, U>
impl<T: PartialOrd, U> TypedSize2D<T, U>
pub fn greater_than(&self, other: &Self) -> BoolVector2D
pub fn lower_than(&self, other: &Self) -> BoolVector2D
Sourceimpl<T: PartialEq, U> TypedSize2D<T, U>
impl<T: PartialEq, U> TypedSize2D<T, U>
pub fn equal(&self, other: &Self) -> BoolVector2D
pub fn not_equal(&self, other: &Self) -> BoolVector2D